==> gambas2-2.0.0.tar.bz2: gambas2-2.0.0/gb.gtk/src/CPictureBox.h <==
/***************************************************************************

  CPictureBox.h

  (c) 2004-2006 - Daniel Campos Fernández <dcamposf@gmail.com>
  
  GTK+ component
  
  Realizado para la Junta de Extremadura. 
  Consejería de Educación Ciencia y Tecnología. 
  Proyecto gnuLinEx
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 1, or (at your option)
  any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

***************************************************************************/

#ifndef __CPICTUREBOX_H
#define __CPICTUREBOX_H

#include "main.h"
#include "CWidget.h"
#include "CPicture.h"
#include "gpicturebox.h"
#include "gmoviebox.h"

#ifndef __CPICTUREBOX_CPP
extern GB_DESC CPictureBoxDesc[];
extern GB_DESC CMovieBoxDesc[];
#else

#define THIS ((CPICTUREBOX *)_object)
#define MTHIS ((CMOVIEBOX *)_object)
#define PBOX ((gPictureBox*)THIS->widget)
#define MBOX ((gMovieBox*)MTHIS->widget)

#endif

typedef  struct 
{
	GB_BASE ob;
	gControl *widget;
	GB_VARIANT_VALUE tag;

	CPICTURE *picture;

} CPICTUREBOX;

typedef  struct 
{
    GB_BASE ob;
    gControl *widget;
	GB_VARIANT_VALUE tag;
	
	char *path;

} CMOVIEBOX;



#endif

==> gambas2-2.11.0.tar.bz2: gambas2-2.11.0/gb.gtk/src/CPictureBox.h <==
/***************************************************************************

  CPictureBox.h

  (c) 2004-2006 - Daniel Campos Fernández <dcamposf@gmail.com>
  
  GTK+ component
  
  Realizado para la Junta de Extremadura. 
  Consejería de Educación Ciencia y Tecnología. 
  Proyecto gnuLinEx
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 1, or (at your option)
  any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

***************************************************************************/

#ifndef __CPICTUREBOX_H
#define __CPICTUREBOX_H

#include "main.h"
#include "CWidget.h"
#include "CPicture.h"
#include "gpicturebox.h"
#include "gmoviebox.h"

#ifndef __CPICTUREBOX_CPP
extern GB_DESC CPictureBoxDesc[];
extern GB_DESC CMovieBoxDesc[];
#else

#define THIS ((CPICTUREBOX *)_object)
#define MTHIS ((CMOVIEBOX *)_object)
#define PBOX ((gPictureBox*)THIS->ob.widget)
#define MBOX ((gMovieBox*)MTHIS->ob.widget)

#endif

typedef  
	struct 
	{
		CWIDGET ob;
		CPICTURE *picture;
	} 
	CPICTUREBOX;

typedef  
	struct 
	{
		CWIDGET ob;
		char *path;
	} 
	CMOVIEBOX;

#endif
